Module error

Module error 

Error types utilized by the backend and its related functions.

Error handlers should be able to match any errors that are to be expected from this library, with one of the Error variants being the entry point. Some of these variants have an additional error type defined for a more exact identification.

Enums

AdvanceCursorBlinkingError
Error that occurs when attempting to advance the frames and set whether a cursor has blinked.
Error
Error that the backend may encounter, with variants that indicate which task the backend was performing when the error occurred.
MeasureError
Error that occurs while measuring the drawing region or the text area, indicating an invalid backend configuration.
SetCursorError
Error that occurs when attempting to set the cursor to an invalid position in the text area.