ConfigureCursorWrapper

Trait ConfigureCursorWrapper 

pub trait ConfigureCursorWrapper<'a> {
    // Required methods
    fn get_cursor_blink(&self) -> Blink;
    fn set_cursor_blink(&mut self, blink: Blink);
    fn get_cursor_colors(&self) -> Colors;
    fn set_cursor_colors(&mut self, colors: Colors);
    fn get_cursor_extent(&self) -> Extent;
    fn set_cursor_extent(&mut self, extent: Extent);
    fn get_cursor_symbol(&self) -> Symbol<'a>;
    fn set_cursor_symbol(&mut self, symbol: Symbol<'a>);
}
Backend configuration retrieval and modification of the CursorWrapper layer.

A backend wrapper that implements this trait allows the fields of a CursorWrapper that are configurable to have their values read or have new values assigned.

Required Methods

Returns the blink animation cycle for the cursor.

Sets the blink animation cycle for the cursor.

fn get_cursor_colors(&self) -> Colors

Returns the method used by the cursor for choosing colors.

fn set_cursor_colors(&mut self, colors: Colors)

Sets the method used by the cursor for choosing colors.

fn get_cursor_extent(&self) -> Extent

Returns the shape that represents the cursor inside of the cell area.

fn set_cursor_extent(&mut self, extent: Extent)

Sets the shape that represents the cursor inside of the cell area.

fn get_cursor_symbol(&self) -> Symbol<'a>

Returns the source of the content that the cursor uses to symbolize itself.

fn set_cursor_symbol(&mut self, symbol: Symbol<'a>)

Sets the source of the content that the cursor uses to symbolize itself.

Implementors

Source

impl<'a, B, D> ConfigureCursorWrapper<'a> for CursorWrapper<'a, B, D>
where B: DrawTargetBackend<D, Error = Error<D::Error>>, D: DrawTarget, D::Error: Debug,

Source

impl<'a, W, B> ConfigureCursorWrapper<'a> for W
where B: ConfigureCursorWrapper<'a>, W: WrapTrait<ConfigureCursorWrapper, Inner = B>,

Blanket implementation of the ConfigureCursorWrapper trait for function call passthrough.