pub trait ConfigureCursorWrapper<'a> {
// Required methods
fn get_cursor_blink(&self) -> Blink;
fn set_cursor_blink(&mut self, blink: Blink);
fn get_cursor_colors(&self) -> Colors;
fn set_cursor_colors(&mut self, colors: Colors);
fn get_cursor_extent(&self) -> Extent;
fn set_cursor_extent(&mut self, extent: Extent);
fn get_cursor_symbol(&self) -> Symbol<'a>;
fn set_cursor_symbol(&mut self, symbol: Symbol<'a>);
}Expand description
Backend configuration retrieval and modification of the CursorWrapper layer.
A backend wrapper that implements this trait allows the fields of a CursorWrapper that are
configurable to have their values read or have new values assigned.
Required Methods
Sourcefn get_cursor_blink(&self) -> Blink
fn get_cursor_blink(&self) -> Blink
Returns the blink animation cycle for the cursor.
Sourcefn set_cursor_blink(&mut self, blink: Blink)
fn set_cursor_blink(&mut self, blink: Blink)
Sets the blink animation cycle for the cursor.
Sourcefn get_cursor_colors(&self) -> Colors
fn get_cursor_colors(&self) -> Colors
Returns the method used by the cursor for choosing colors.
Sourcefn set_cursor_colors(&mut self, colors: Colors)
fn set_cursor_colors(&mut self, colors: Colors)
Sets the method used by the cursor for choosing colors.
Sourcefn get_cursor_extent(&self) -> Extent
fn get_cursor_extent(&self) -> Extent
Returns the shape that represents the cursor inside of the cell area.
Sourcefn set_cursor_extent(&mut self, extent: Extent)
fn set_cursor_extent(&mut self, extent: Extent)
Sets the shape that represents the cursor inside of the cell area.
Sourcefn get_cursor_symbol(&self) -> Symbol<'a>
fn get_cursor_symbol(&self) -> Symbol<'a>
Returns the source of the content that the cursor uses to symbolize itself.
Sourcefn set_cursor_symbol(&mut self, symbol: Symbol<'a>)
fn set_cursor_symbol(&mut self, symbol: Symbol<'a>)
Sets the source of the content that the cursor uses to symbolize itself.
Implementors
impl<'a, B, D> ConfigureCursorWrapper<'a> for CursorWrapper<'a, B, D>
impl<'a, W, B> ConfigureCursorWrapper<'a> for Wwhere
B: ConfigureCursorWrapper<'a>,
W: WrapTrait<ConfigureCursorWrapper, Inner = B>,
Blanket implementation of the ConfigureCursorWrapper trait for function call passthrough.